==> SugarCE-5.5.1.zip: SugarCE-Full-5.5.1/modules/Cases/Dashlets/MyCasesDashlet/MyCasesDashlet.data.php <==
<?php
if(!defined('sugarEntry') || !sugarEntry) die('Not A Valid Entry Point');
/*********************************************************************************
 * SugarCRM is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2010 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/



global $current_user;

$dashletData['MyCasesDashlet']['searchFields'] = array('priority'         => array('default' => ''),
                                                       'status'           => array('default' => array('Assigned', 'New', 'Pending Input')),
                                                       'date_entered'     => array('default' => ''),
                                                       'date_modified'    => array('default' => ''),
                                                       'assigned_user_id' => array('type'    => 'assigned_user_name', 
                                                                                   'default' => $current_user->name));
$dashletData['MyCasesDashlet']['columns'] = array('case_number' => array('width'   => '6',
                                                                         'label'   => 'LBL_NUMBER',
                                                                         'default' => true),
                                                  'name' => array('width'    => '40', 
                                                                  'label'   => 'LBL_LIST_SUBJECT',
                                                                  'link'    => true,
                                                                  'default' => true), 
                                                  'account_name' => array('width' => '29',
                                                                          'module' => 'Cases',
                                                                          'id' => 'ACCOUNT_ID',
                                                                          'link' => false, 
                                                                          'label' => 'LBL_ACCOUNT_NAME',
                                                                          'sortable' => false),
                                                  'priority' => array('width'   => '15', 
                                                                      'label'   => 'LBL_PRIORITY',
                                                                      'default' => true), 
                                                  'status' => array('width'   => '8', 
                                                                    'label'   => 'LBL_STATUS',
                                                                    'default' => true),                                            
                                                  'resolution' => array('width' => '8', 
                                                                        'label' => 'LBL_RESOLUTION'),
                                                  'date_entered' => array('width'   => '15', 
                                                                          'label'   => 'LBL_DATE_ENTERED'),
                                                  'date_modified' => array('width'   => '15', 
                                                                           'label'   => 'LBL_DATE_MODIFIED'),    
                                                  'created_by' => array('width'   => '8', 
                                                                        'label'   => 'LBL_CREATED'),
                                                  'assigned_user_name' => array('width'   => '8', 
                                                                                'label'   => 'LBL_LIST_ASSIGNED_USER'),
                                                 );
?>

==> SugarCE-6.2.1.zip: SugarCE-Full-6.2.1/modules/Cases/Dashlets/MyCasesDashlet/MyCasesDashlet.data.php <==
<?php
if(!defined('sugarEntry') || !sugarEntry) die('Not A Valid Entry Point');
/*********************************************************************************
 * SugarCRM Community Edition is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2011 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/




global $current_user;

$dashletData['MyCasesDashlet']['searchFields'] = array('date_entered'     => array('default' => ''),
													   'priority'         => array('default' => ''),
                                                       'status'           => array('default' => array('Assigned', 'New', 'Pending Input')),
                                                       
													   'name'             => array('default' => ''),
												       'type'             => array('default' => ''),
                                                       //'date_modified'    => array('default' => ''),
                                                       'assigned_user_id' => array('type'    => 'assigned_user_name',
																				   'label'   => 'LBL_ASSIGNED_TO',
                                                                                   'default' => $current_user->name));
$dashletData['MyCasesDashlet']['columns'] = array('case_number' => array('width'   => '6',
                                                                         'label'   => 'LBL_NUMBER',
                                                                         'default' => true),
                                                  'name' => array('width'    => '40', 
                                                                  'label'   => 'LBL_LIST_SUBJECT',
                                                                  'link'    => true,
                                                                  'default' => true), 
                                                  'account_name' => array('width' => '29',
                                                                          'link' => true,
                                                                          'module' => 'Accounts',
                                                                          'id' => 'ACCOUNT_ID',
                                                                          'ACLTag' => 'ACCOUNT', 
                                                                          'label' => 'LBL_ACCOUNT_NAME',
                                                                          'related_fields' => array('account_id')),
                                                  'priority' => array('width'   => '15', 
                                                                      'label'   => 'LBL_PRIORITY',
                                                                      'default' => true), 
                                                  'status' => array('width'   => '8', 
                                                                    'label'   => 'LBL_STATUS',
                                                                    'default' => true),                                            
                                                  'resolution' => array('width' => '8', 
                                                                        'label' => 'LBL_RESOLUTION'),
                                                  'date_entered' => array('width'   => '15', 
                                                                          'label'   => 'LBL_DATE_ENTERED'),
                                                  'date_modified' => array('width'   => '15', 
                                                                           'label'   => 'LBL_DATE_MODIFIED'),    
                                                  'created_by' => array('width'   => '8', 
                                                                        'label'   => 'LBL_CREATED'),
                                                  'assigned_user_name' => array('width'   => '8', 
                                                                                'label'   => 'LBL_LIST_ASSIGNED_USER'),
                                                 );
?>
